@@ -2,10 +2,10 @@ import nolds
 import os
 import mne
 import json
-
+import numpy as np
 
 # -- epileptologie-bonn.de --
-def txt_lyapunv(txt):
+def txt_lyapunov(txt):
     archivo = open(txt,'r')
     Serie=[ int(dat[:dat.find('\n')]) for dat in archivo]
     lyapunov = nolds.lyap_r(Serie)
@@ -26,7 +26,7 @@ def txt_entropy(txt, dim):
     samp = nolds.sampen(Serie, dim)
     return samp
 #--- BRAIN VISION ----
-def vhdr_lyapunv(vhdr,tmax,inter,electrodes):
+def vhdr_lyapunov(vhdr,tmax,inter,electrodes):
     div=tmax/inter
     sep_time=[]
     for i in range(inter):
@@ -176,7 +176,7 @@ def vhdr_entropy(vhdr,dim,tmax,inter,electrodes):
         data.append(EEG)
     return data
 # --- EDF ---
-def edf_lyapunv(edf,tmax,inter,electrodes):
+def edf_lyapunov(edf,tmax,inter,electrodes):
     div=tmax/inter
     sep_time=[]
     for i in range(inter):
@@ -318,7 +318,7 @@ def edf_entropy(edf,dim,tmax,inter,electrodes):
         data.append(EEG)
     return data
 # --- BDF ---
-def bdf_lyapunv(bdf,tmax,inter,electrodes):
+def bdf_lyapunov(bdf,tmax,inter,electrodes):
     div=tmax/inter
     sep_time=[]
     for i in range(inter):
